:root{
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 161;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:#9747ff;
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

.editor-styles-wrapper .wp-block{
  margin-left:auto;
  margin-right:auto;
}

html :where(.editor-styles-wrapper){
  padding:8px;
}
html :where(.editor-styles-wrapper) .block-editor-block-list__layout.is-root-container>.wp-block[data-align=full]{
  margin-left:-8px;
  margin-right:-8px;
}

html :where(.wp-block){
  margin-bottom:28px;
  margin-top:28px;
  max-width:840px;
}
html :where(.wp-block)[data-align=wide]{
  max-width:1100px;
}
html :where(.wp-block)[data-align=full]{
  max-width:none;
}
html :where(.wp-block)[data-align=left],html :where(.wp-block)[data-align=right]{
  height:0;
  width:100%;
}
html :where(.wp-block)[data-align=left]:before,html :where(.wp-block)[data-align=right]:before{
  content:none;
}
html :where(.wp-block)[data-align=left]>*{
  float:left;
  margin-right:2em;
}
html :where(.wp-block)[data-align=right]>*{
  float:right;
  margin-left:2em;
}
html :where(.wp-block)[data-align=full],html :where(.wp-block)[data-align=wide]{
  clear:both;
}

.wp-block-group>[data-align=full]{
  margin-left:auto;
  margin-right:auto;
}

.wp-block-group.has-background>[data-align=full]{
  margin-right:-30px;
  width:calc(100% + 60px);
}
[data-align=full] .wp-block-group>.wp-block{
  padding-left:14px;
  padding-right:14px;
}
@media (min-width:600px){
  [data-align=full] .wp-block-group>.wp-block{
    padding-left:0;
    padding-right:0;
  }
}
[data-align=full] .wp-block-group>[data-align=full]{
  max-width:none;
  padding-left:0;
  padding-right:0;
  right:0;
  width:100%;
}
[data-align=full] .wp-block-group.has-background>[data-align=full]{
  width:calc(100% + 60px);
}